finalize_courier_task

Function finalize_courier_task 

pub fn finalize_courier_task(
    ctx: &mut NpcCtx<'_, '_>,
    quest_id: QuestId,
    read_only: bool,
) -> bool
Checks if a courier quest can be completed based on inventory and entity presence.

The inventory check/consume operation is atomic. All inventory items’ presence are verified first, then the items are subsequently removed in the same transaction/lock.

That being said, if read_only is true, the inventory will not be modified, only checked.

This should support checking for completion regardless of if it’s being completed by a player or an rtsim NPC.