pub fn get_nearest_spot(
ctx: &mut NpcCtx<'_, '_>,
quest: CourierQuest,
target_chunk: Vec2<i32>,
) -> Option<Vec2<i32>>Expand description
Finds the nearest chunk position that contains the appropriate kind of spot
for this courier quest variant. For example, if you have a Gnarling Carving
quest, this will search nearby for the nearest Gnarling Totem spot and
return the chunk position (not the world position, you’ll need to convert it
to wpos).
The target_chunk needs to be predetermined in order to satisfy compiler
checks.